@@ -22,17 +22,13 @@
 
 */
 
+#include <QFileDialog>
+#include <QStandardPaths>
 
-#include <kfiledialog.h>
-#include <KGlobal>
-#include <KUrl>
-#include <kio/netaccess.h>
 #include <KLocalizedString>
 #include <kmessagebox.h>
-#include <kstandarddirs.h>
 #include <kacceleratormanager.h>
 #include <kactioncollection.h>
-#include <kmenu.h>
 #include <KNewStuff3/KNS3/DownloadDialog>
 #include <KConfigGroup>
 
@@ -88,10 +84,9 @@ void Workspace::readProperties( const KConfigGroup& cfg )
     selectedSheets.replace(oldSystemLoad, QStringLiteral("SystemLoad2.sgrd"));
   }
 
-  KStandardDirs* kstd = KGlobal::dirs();
   QString filename;
   for ( QStringList::Iterator it = selectedSheets.begin(); it != selectedSheets.end(); ++it ) {
-    filename = kstd->findResource( "data", "ksysguard/" + *it);
+    filename = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "ksysguard/" + *it);
     if(!filename.isEmpty()) {
       restoreWorkSheet( filename, false);
     }
@@ -111,11 +106,10 @@ QString Workspace::makeNameForNewSheet() const
   int i = 1;
   bool found = false;
   QString sheetName;
-  KStandardDirs* kstd = KGlobal::dirs();
   do {
     sheetName = i18n( "Sheet %1" ,  i++ );
     //Check we don't have any existing files with this name
-    found = !(kstd->findResource( "data", "ksysguard/" + sheetName + ".sgrd").isEmpty());
+    found = !(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "ksysguard/" + sheetName + ".sgrd").isEmpty());
 
     //Check if we have any sheets with the same tab name or file name
     for(int i = 0; !found && i < mSheetList.size(); i++)
@@ -187,29 +181,24 @@ bool Workspace::saveOnQuit()
 
 void Workspace::importWorkSheet()
 {
-  KUrl url = KFileDialog::getOpenUrl( QUrl(), i18n("*.sgrd|Sensor Files (*.sgrd)"), this, i18n( "Select Tab File to Import" ) );
-
+  QUrl url = QFileDialog::getOpenFileUrl(this,
+                                         i18n("Select Tab File to Import"),
+                                         QUrl(),
+                                         QStringLiteral("Sensor Files (*.sgrd)"));
   importWorkSheet( url );
 }
 
-void Workspace::importWorkSheet( const KUrl &url )
+void Workspace::importWorkSheet( const QUrl &url )
 {
   if ( url.isEmpty() )
     return;
 
-  /* It's probably not worth the effort to make this really network
-   * transparent. Unless s/o beats me up I use this pseudo transparent
-   * code. */
-  QString tmpFile;
-  KIO::NetAccess::download( url, tmpFile, this );
-
   // Import sheet from file.
-  if ( !restoreWorkSheet( tmpFile ) )
+  if (!restoreWorkSheet(url.toLocalFile())) {
     return;
+  }
 
   mSheetList.last()->setFileName( makeNameForNewSheet() + ".sgrd");
-
-  KIO::NetAccess::removeTempFile( tmpFile );
 }
 
 bool Workspace::saveWorkSheet( WorkSheet *sheet )
@@ -219,8 +208,7 @@ bool Workspace::saveWorkSheet( WorkSheet *sheet )
     return false;
   }
 
-  KStandardDirs* kstd = KGlobal::dirs();
-  QString fileName = kstd->saveLocation( "data", QStringLiteral("ksysguard")) + sheet->fileName();
+  QString fileName = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + sheet->fileName();
 
   if ( !sheet->save( fileName ) ) {
     return false;
@@ -242,8 +230,10 @@ void Workspace::exportWorkSheet( WorkSheet *sheet )
 
   QString fileName;
   do {
-    fileName = KFileDialog::getSaveFileName( QUrl(QString(tabText(indexOf( currentWidget() ))+ ".sgrd")),
-		                    QStringLiteral("*.sgrd"), this, i18n("Export Tab") );
+    fileName = QFileDialog::getSaveFileName(this,
+                                            i18n("Export Tab"),
+                                            QString(tabText(indexOf(currentWidget())) + ".sgrd"),
+                                            QStringLiteral("Sensor Files (*.sgrd)"));
     if ( fileName.isEmpty() )
       return;
 
